@@ -15,7 +15,9 @@ def test_hypotest_validity(example_model):
     )
     m = pyhf.simplemodels.uncorrelated_background([5], [50], [5])
     pyhf_cls = pyhf.infer.hypotest(1, m.expected_data(analytic_pars), m)
-    np.allclose(relaxed_cls, pyhf_cls)
+    assert np.allclose(
+        relaxed_cls, pyhf_cls, rtol=0.3  # high rtol for a very loose test...
+    )  # ...tested working without dummy_pyhf on a pyhf fork, but not main yet
 
 
 def test_hypotest_grad():
